---
name: zfit usage question
about: Questions about the usage and best ways in zfit
title: "[QUESTION]"
labels: ''
assignees: ''

---

Please use preferably one of the following channels:
 - read the FAQ, it may holds your answer already
 - [ask on StackOverflow](https://stackoverflow.com/questions/ask) with 
the **zfit** tag (so we also get notified).
 - if you want to ask immediately a broader community, feel free to ask in the [Gitter channel of zfit](https://gitter.im/zfit/zfit)
 - or post an issue here with the question
